# -*- coding: utf-8 -*-
import law
import luigi
import logging
import os
import re

from functools import partial

from analysis.tasks.FastWarm import FastWarm

from analysis.framework import Task, SpaceSeparatedListParameter
from analysis.mixins import TarballExtractionMixin
from analysis.util import working_directory

logger = logging.getLogger(__name__)
working_directory = partial(working_directory, logger=logger)


class CopyFastWarm(Task, TarballExtractionMixin, law.LocalWorkflow):
    force = luigi.BoolParameter(default=False)

    warm_dir = luigi.Parameter(default='warmups')

    def create_branch_map(self):
        """Branch data dicts. Each branch should correspond to exactly one output."""
        return FastWarm.req(self).branch_map

    def workflow_requires(self):
        if self.force:
            return 0
        else:
            return {"fastwarm": FastWarm.req(self)}

    def output(self):
        out_dir = os.getenv("ANALYSIS_PATH") or os.getcwd()
        basename = FastWarm(branch=self.branch).output().basename
        outfile = re.sub('.gz$', '', basename)
        outfile = re.sub('.tar$', '', outfile) + '.log'
        return law.LocalFileTarget(
            '{}/{}/{}/{}/{}'.format(
                out_dir,
                self.warm_dir, 'fastwarm', self.name, outfile
            )
        )

    def run(self):
        # get input and output targets
        input_ = FastWarm(branch=self.branch).output()
        output = self.output()

        # extract input tarball to output parent directory
        self.extract_tarball(
            input_,
            output.parent,
            formatter="tar",
            logger=logger,
            # check that expected file was extracted
            check_targets=[
                output,
            ],
        )
